# RobotHub-OAK

This repository contains the code for the integration of [DepthAI SDK](https://github.com/luxonis/depthai) into
RobotHub.

> **This library is intended to be only used with RobotHub.**

## Documentation

Please visit [RobotHub documentation page](https://hub-docs.luxonis.com/).

## Installation

To install this package, run the following command in your terminal window

```
$ python3 -m pip install robothub-oak
```

## Examples

You can find examples in the [robothub-examples](https://github.com/luxonis/robothub-examples) repository.

## License

This project is licensed under the terms of the MIT license.